@@ -26,16 +26,18 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "quakedef.h"
 
-qmodel_t	*loadmodel;
-char	loadname[32];	// for hunk tags
+static qmodel_t*	loadmodel;
+static char	loadname[32];	// for hunk tags
 
-void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer);
-void Mod_LoadBrushModel (qmodel_t *mod, void *buffer);
-void Mod_LoadAliasModel (qmodel_t *mod, void *buffer);
-qmodel_t *Mod_LoadModel (qmodel_t *mod, qboolean crash);
+static void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer);
+static void Mod_LoadBrushModel (qmodel_t *mod, void *buffer);
+static void Mod_LoadAliasModel (qmodel_t *mod, void *buffer);
+static qmodel_t *Mod_LoadModel (qmodel_t *mod, qboolean crash);
 
-cvar_t	external_ents = {"external_ents", "1", CVAR_ARCHIVE};
-cvar_t	external_vis = {"external_vis", "1", CVAR_ARCHIVE};
+static void Mod_Print (void);
+
+static cvar_t	external_ents = {"external_ents", "1", CVAR_ARCHIVE};
+static cvar_t	external_vis = {"external_vis", "1", CVAR_ARCHIVE};
 
 static byte	*mod_novis;
 static int	mod_novis_capacity;
@@ -44,8 +46,8 @@ static byte	*mod_decompressed;
 static int	mod_decompressed_capacity;
 
 #define	MAX_MOD_KNOWN	2048 /*johnfitz -- was 512 */
-qmodel_t	mod_known[MAX_MOD_KNOWN];
-int		mod_numknown;
+static qmodel_t	mod_known[MAX_MOD_KNOWN];
+static int		mod_numknown;
 
 texture_t	*r_notexture_mip; //johnfitz -- moved here from r_main.c
 texture_t	*r_notexture_mip2; //johnfitz -- used for non-lightmapped surfs with a missing texture
@@ -61,6 +63,8 @@ void Mod_Init (void)
 	Cvar_RegisterVariable (&external_vis);
 	Cvar_RegisterVariable (&external_ents);
 
+	Cmd_AddCommand ("mcache", Mod_Print);
+
 	//johnfitz -- create notexture miptex
 	r_notexture_mip = (texture_t *) Hunk_AllocName (sizeof(texture_t), "r_notexture_mip");
 	strcpy (r_notexture_mip->name, "notexture");
@@ -130,7 +134,7 @@ mleaf_t *Mod_PointInLeaf (vec3_t p, qmodel_t *model)
 Mod_DecompressVis
 ===================
 */
-byte *Mod_DecompressVis (byte *in, qmodel_t *model)
+static byte *Mod_DecompressVis (byte *in, qmodel_t *model)
 {
 	int		c;
 	byte	*out;
@@ -221,11 +225,13 @@ void Mod_ClearAll (void)
 	qmodel_t	*mod;
 
 	for (i=0 , mod=mod_known ; i<mod_numknown ; i++, mod++)
+	{
 		if (mod->type != mod_alias)
 		{
 			mod->needload = true;
 			TexMgr_FreeTexturesForOwner (mod); //johnfitz
 		}
+	}
 }
 
 void Mod_ResetAll (void)
@@ -235,7 +241,7 @@ void Mod_ResetAll (void)
 
 	//ericw -- free alias model VBOs
 	GLMesh_DeleteVertexBuffers ();
-	
+
 	for (i=0 , mod=mod_known ; i<mod_numknown ; i++, mod++)
 	{
 		if (!mod->needload) //otherwise Mod_ClearAll() did it already
@@ -251,7 +257,7 @@ Mod_FindName
 
 ==================
 */
-qmodel_t *Mod_FindName (const char *name)
+static qmodel_t *Mod_FindName (const char *name)
 {
 	int		i;
 	qmodel_t	*mod;
@@ -263,8 +269,10 @@ qmodel_t *Mod_FindName (const char *name)
 // search the currently loaded models
 //
 	for (i=0 , mod=mod_known ; i<mod_numknown ; i++, mod++)
+	{
 		if (!strcmp (mod->name, name) )
 			break;
+	}
 
 	if (i == mod_numknown)
 	{
@@ -304,7 +312,7 @@ Mod_LoadModel
 Loads a model into the cache
 ==================
 */
-qmodel_t *Mod_LoadModel (qmodel_t *mod, qboolean crash)
+static qmodel_t *Mod_LoadModel (qmodel_t *mod, qboolean crash)
 {
 	byte	*buf;
 	byte	stackbuf[1024];		// avoid dirtying the cache heap
@@ -398,19 +406,21 @@ qmodel_t *Mod_ForName (const char *name, qboolean crash)
 ===============================================================================
 */
 
-byte	*mod_base;
+static byte	*mod_base;
 
 /*
 =================
 Mod_CheckFullbrights -- johnfitz
 =================
 */
-qboolean Mod_CheckFullbrights (byte *pixels, int count)
+static qboolean Mod_CheckFullbrights (byte *pixels, int count)
 {
 	int i;
 	for (i = 0; i < count; i++)
+	{
 		if (*pixels++ > 223)
 			return true;
+	}
 	return false;
 }
 
@@ -422,7 +432,7 @@ Quake64 bsp
 Check if we have any missing textures in the array
 =================
 */
-qboolean Mod_CheckAnimTextureArrayQ64(texture_t *anims[], int numTex)
+static qboolean Mod_CheckAnimTextureArrayQ64(texture_t *anims[], int numTex)
 {
 	int i;
 
@@ -439,7 +449,7 @@ qboolean Mod_CheckAnimTextureArrayQ64(texture_t *anims[], int numTex)
 Mod_LoadTextures
 =================
 */
-void Mod_LoadTextures (lump_t *l)
+static void Mod_LoadTextures (lump_t *l)
 {
 	int		i, j, pixels, num, maxanim, altmax;
 	miptex_t	*mt;
@@ -452,7 +462,7 @@ void Mod_LoadTextures (lump_t *l)
 	int			nummiptex;
 	src_offset_t		offset;
 	int			mark, fwidth, fheight;
-	char		filename[MAX_OSPATH], filename2[MAX_OSPATH], mapname[MAX_OSPATH];
+	char		filename[MAX_OSPATH], mapname[MAX_OSPATH];
 	byte		*data;
 	extern byte *hunk_base;
 //johnfitz
@@ -508,7 +518,7 @@ void Mod_LoadTextures (lump_t *l)
 		if (((byte*)(mt+1) + pixels) > (mod_base + l->fileofs + l->filelen))
 		{
 			Con_DPrintf("Texture %s extends past end of lump\n", mt->name);
-			pixels = q_max(0, (mod_base + l->fileofs + l->filelen) - (byte*)(mt+1));
+			pixels = q_max(0L, (long)((mod_base + l->fileofs + l->filelen) - (byte*)(mt+1)));
 		}
 
 		tx->update_warp = false; //johnfitz
@@ -533,9 +543,9 @@ void Mod_LoadTextures (lump_t *l)
 			if (!q_strncasecmp(tx->name,"sky",3)) //sky texture //also note -- was Q_strncmp, changed to match qbsp
 			{
 				if (loadmodel->bspversion == BSPVERSION_QUAKE64)
-					Sky_LoadTextureQ64 (tx);
+					Sky_LoadTextureQ64 (loadmodel, tx);
 				else
-					Sky_LoadTexture (tx);
+					Sky_LoadTexture (loadmodel, tx);
 			}
 			else if (tx->name[0] == '*') //warping texture
 			{
@@ -597,6 +607,7 @@ void Mod_LoadTextures (lump_t *l)
 				//now load whatever we found
 				if (data) //load external image
 				{
+					char filename2[MAX_OSPATH];
 					tx->gltexture = TexMgr_LoadImage (loadmodel, filename, fwidth, fheight,
 						SRC_RGBA, data, filename, 0, TEXPREF_MIPMAP | extraflags );
 
@@ -612,7 +623,7 @@ void Mod_LoadTextures (lump_t *l)
 
 					if (data)
 						tx->fullbright = TexMgr_LoadImage (loadmodel, filename2, fwidth, fheight,
-							SRC_RGBA, data, filename, 0, TEXPREF_MIPMAP | extraflags );
+							SRC_RGBA, data, filename2, 0, TEXPREF_MIPMAP | extraflags );
 				}
 				else //use the texture from the bsp file
 				{
@@ -744,7 +755,7 @@ void Mod_LoadTextures (lump_t *l)
 Mod_LoadLighting -- johnfitz -- replaced with lit support code via lordhavoc
 =================
 */
-void Mod_LoadLighting (lump_t *l)
+static void Mod_LoadLighting (lump_t *l)
 {
 	int i, mark;
 	byte *in, *out, *data;
@@ -840,7 +851,7 @@ void Mod_LoadLighting (lump_t *l)
 Mod_LoadVisibility
 =================
 */
-void Mod_LoadVisibility (lump_t *l)
+static void Mod_LoadVisibility (lump_t *l)
 {
 	loadmodel->viswarn = false;
 	if (!l->filelen)
@@ -858,7 +869,7 @@ void Mod_LoadVisibility (lump_t *l)
 Mod_LoadEntities
 =================
 */
-void Mod_LoadEntities (lump_t *l)
+static void Mod_LoadEntities (lump_t *l)
 {
 	char	basemapname[MAX_QPATH];
 	char	entfilename[MAX_QPATH];
@@ -922,7 +933,7 @@ _load_embedded:
 Mod_LoadVertexes
 =================
 */
-void Mod_LoadVertexes (lump_t *l)
+static void Mod_LoadVertexes (lump_t *l)
 {
 	dvertex_t	*in;
 	mvertex_t	*out;
@@ -950,7 +961,7 @@ void Mod_LoadVertexes (lump_t *l)
 Mod_LoadEdges
 =================
 */
-void Mod_LoadEdges (lump_t *l, int bsp2)
+static void Mod_LoadEdges (lump_t *l, int bsp2)
 {
 	medge_t *out;
 	int 	i, count;
@@ -1000,7 +1011,7 @@ void Mod_LoadEdges (lump_t *l, int bsp2)
 Mod_LoadTexinfo
 =================
 */
-void Mod_LoadTexinfo (lump_t *l)
+static void Mod_LoadTexinfo (lump_t *l)
 {
 	texinfo_t *in;
 	mtexinfo_t *out;
@@ -1057,7 +1068,7 @@ CalcSurfaceExtents
 Fills in s->texturemins[] and s->extents[]
 ================
 */
-void CalcSurfaceExtents (msurface_t *s)
+static void CalcSurfaceExtents (msurface_t *s)
 {
 	float	mins[2], maxs[2], val;
 	int		i,j, e;
@@ -1127,7 +1138,7 @@ Mod_PolyForUnlitSurface -- johnfitz -- creates polys for unlightmapped surfaces
 TODO: merge this into BuildSurfaceDisplayList?
 ================
 */
-void Mod_PolyForUnlitSurface (msurface_t *fa)
+static void Mod_PolyForUnlitSurface (msurface_t *fa)
 {
 	vec3_t		verts[64];
 	int			numverts, i, lindex;
@@ -1172,7 +1183,7 @@ void Mod_PolyForUnlitSurface (msurface_t *fa)
 Mod_CalcSurfaceBounds -- johnfitz -- calculate bounding box for per-surface frustum culling
 =================
 */
-void Mod_CalcSurfaceBounds (msurface_t *s)
+static void Mod_CalcSurfaceBounds (msurface_t *s)
 {
 	int			i, e;
 	mvertex_t	*v;
@@ -1209,7 +1220,7 @@ void Mod_CalcSurfaceBounds (msurface_t *s)
 Mod_LoadFaces
 =================
 */
-void Mod_LoadFaces (lump_t *l, qboolean bsp2)
+static void Mod_LoadFaces (lump_t *l, qboolean bsp2)
 {
 	dsface_t	*ins;
 	dlface_t	*inl;
@@ -1340,7 +1351,7 @@ void Mod_LoadFaces (lump_t *l, qboolean bsp2)
 Mod_SetParent
 =================
 */
-void Mod_SetParent (mnode_t *node, mnode_t *parent)
+static void Mod_SetParent (mnode_t *node, mnode_t *parent)
 {
 	node->parent = parent;
 	if (node->contents < 0)
@@ -1354,7 +1365,7 @@ void Mod_SetParent (mnode_t *node, mnode_t *parent)
 Mod_LoadNodes
 =================
 */
-void Mod_LoadNodes_S (lump_t *l)
+static void Mod_LoadNodes_S (lump_t *l)
 {
 	int			i, j, count, p;
 	dsnode_t	*in;
@@ -1410,7 +1421,7 @@ void Mod_LoadNodes_S (lump_t *l)
 	}
 }
 
-void Mod_LoadNodes_L1 (lump_t *l)
+static void Mod_LoadNodes_L1 (lump_t *l)
 {
 	int			i, j, count, p;
 	dl1node_t	*in;
@@ -1462,7 +1473,7 @@ void Mod_LoadNodes_L1 (lump_t *l)
 	}
 }
 
-void Mod_LoadNodes_L2 (lump_t *l)
+static void Mod_LoadNodes_L2 (lump_t *l)
 {
 	int			i, j, count, p;
 	dl2node_t	*in;
@@ -1514,7 +1525,7 @@ void Mod_LoadNodes_L2 (lump_t *l)
 	}
 }
 
-void Mod_LoadNodes (lump_t *l, int bsp2)
+static void Mod_LoadNodes (lump_t *l, int bsp2)
 {
 	if (bsp2 == 2)
 		Mod_LoadNodes_L2(l);
@@ -1526,7 +1537,7 @@ void Mod_LoadNodes (lump_t *l, int bsp2)
 	Mod_SetParent (loadmodel->nodes, NULL);	// sets nodes and leafs
 }
 
-void Mod_ProcessLeafs_S (dsleaf_t *in, int filelen)
+static void Mod_ProcessLeafs_S (dsleaf_t *in, int filelen)
 {
 	mleaf_t		*out;
 	int			i, j, count, p;
@@ -1538,7 +1549,7 @@ void Mod_ProcessLeafs_S (dsleaf_t *in, int filelen)
 
 	//johnfitz
 	if (count > 32767)
-		Host_Error ("Mod_LoadLeafs: %i leafs exceeds limit of 32767.\n", count);
+		Host_Error ("Mod_LoadLeafs: %i leafs exceeds limit of 32767.", count);
 	//johnfitz
 
 	loadmodel->leafs = out;
@@ -1572,7 +1583,7 @@ void Mod_ProcessLeafs_S (dsleaf_t *in, int filelen)
 	}
 }
 
-void Mod_ProcessLeafs_L1 (dl1leaf_t *in, int filelen)
+static void Mod_ProcessLeafs_L1 (dl1leaf_t *in, int filelen)
 {
 	mleaf_t		*out;
 	int			i, j, count, p;
@@ -1615,7 +1626,7 @@ void Mod_ProcessLeafs_L1 (dl1leaf_t *in, int filelen)
 	}
 }
 
-void Mod_ProcessLeafs_L2 (dl2leaf_t *in, int filelen)
+static void Mod_ProcessLeafs_L2 (dl2leaf_t *in, int filelen)
 {
 	mleaf_t		*out;
 	int			i, j, count, p;
@@ -1663,7 +1674,7 @@ void Mod_ProcessLeafs_L2 (dl2leaf_t *in, int filelen)
 Mod_LoadLeafs
 =================
 */
-void Mod_LoadLeafs (lump_t *l, int bsp2)
+static void Mod_LoadLeafs (lump_t *l, int bsp2)
 {
 	void *in = (void *)(mod_base + l->fileofs);
 
@@ -1680,7 +1691,7 @@ void Mod_LoadLeafs (lump_t *l, int bsp2)
 Mod_LoadClipnodes
 =================
 */
-void Mod_LoadClipnodes (lump_t *l, qboolean bsp2)
+static void Mod_LoadClipnodes (lump_t *l, qboolean bsp2)
 {
 	dsclipnode_t *ins;
 	dlclipnode_t *inl;
@@ -1788,7 +1799,7 @@ Mod_MakeHull0
 Duplicate the drawing hull structure as a clipping hull
 =================
 */
-void Mod_MakeHull0 (void)
+static void Mod_MakeHull0 (void)
 {
 	mnode_t		*in, *child;
 	mclipnode_t *out; //johnfitz -- was dclipnode_t
@@ -1825,7 +1836,7 @@ void Mod_MakeHull0 (void)
 Mod_LoadMarksurfaces
 =================
 */
-void Mod_LoadMarksurfaces (lump_t *l, int bsp2)
+static void Mod_LoadMarksurfaces (lump_t *l, int bsp2)
 {
 	int		i, j, count;
 	msurface_t **out;
@@ -1883,7 +1894,7 @@ void Mod_LoadMarksurfaces (lump_t *l, int bsp2)
 Mod_LoadSurfedges
 =================
 */
-void Mod_LoadSurfedges (lump_t *l)
+static void Mod_LoadSurfedges (lump_t *l)
 {
 	int		i, count;
 	int		*in, *out;
@@ -1907,7 +1918,7 @@ void Mod_LoadSurfedges (lump_t *l)
 Mod_LoadPlanes
 =================
 */
-void Mod_LoadPlanes (lump_t *l)
+static void Mod_LoadPlanes (lump_t *l)
 {
 	int			i, j;
 	mplane_t	*out;
@@ -1945,7 +1956,7 @@ void Mod_LoadPlanes (lump_t *l)
 RadiusFromBounds
 =================
 */
-float RadiusFromBounds (vec3_t mins, vec3_t maxs)
+static float RadiusFromBounds (vec3_t mins, vec3_t maxs)
 {
 	int		i;
 	vec3_t	corner;
@@ -1963,7 +1974,7 @@ float RadiusFromBounds (vec3_t mins, vec3_t maxs)
 Mod_LoadSubmodels
 =================
 */
-void Mod_LoadSubmodels (lump_t *l)
+static void Mod_LoadSubmodels (lump_t *l)
 {
 	dmodel_t	*in;
 	dmodel_t	*out;
@@ -2013,7 +2024,8 @@ Therefore, the bounding box of the hull can be constructed entirely
 from axial planes found in the clipnodes for that hull.
 =================
 */
-void Mod_BoundsFromClipNode (qmodel_t *mod, int hull, int nodenum)
+#if 0 /* disabled for now -- see in Mod_SetupSubmodels()  */
+static void Mod_BoundsFromClipNode (qmodel_t *mod, int hull, int nodenum)
 {
 	mplane_t	*plane;
 	mclipnode_t	*node;
@@ -2052,6 +2064,7 @@ void Mod_BoundsFromClipNode (qmodel_t *mod, int hull, int nodenum)
 	Mod_BoundsFromClipNode (mod, hull, node->children[0]);
 	Mod_BoundsFromClipNode (mod, hull, node->children[1]);
 }
+#endif /* #if 0 */
 
 /* EXTERNAL VIS FILE SUPPORT:
  */
@@ -2153,7 +2166,7 @@ static void Mod_LoadLeafsExternal(FILE* f)
 Mod_LoadBrushModel
 =================
 */
-void Mod_LoadBrushModel (qmodel_t *mod, void *buffer)
+static void Mod_LoadBrushModel (qmodel_t *mod, void *buffer)
 {
 	int			i, j;
 	int			bsp2;
@@ -2314,17 +2327,14 @@ mtriangle_t	triangles[MAXALIASTRIS];
 // a pose is a single set of vertexes.  a frame may be
 // an animating sequence of poses
 trivertx_t	*poseverts[MAXALIASFRAMES];
-int			posenum;
-
-byte		**player_8bit_texels_tbl;
-byte		*player_8bit_texels;
+static int		posenum;
 
 /*
 =================
 Mod_LoadAliasFrame
 =================
 */
-void * Mod_LoadAliasFrame (void * pin, maliasframedesc_t *frame)
+static void *Mod_LoadAliasFrame (void * pin, maliasframedesc_t *frame)
 {
 	trivertx_t		*pinframe;
 	int				i;
@@ -2347,7 +2357,6 @@ void * Mod_LoadAliasFrame (void * pin, maliasframedesc_t *frame)
 		frame->bboxmax.v[i] = pdaliasframe->bboxmax.v[i];
 	}
 
-
 	pinframe = (trivertx_t *)(pdaliasframe + 1);
 
 	poseverts[posenum] = pinframe;
@@ -2364,7 +2373,7 @@ void * Mod_LoadAliasFrame (void * pin, maliasframedesc_t *frame)
 Mod_LoadAliasGroup
 =================
 */
-void *Mod_LoadAliasGroup (void * pin,  maliasframedesc_t *frame)
+static void *Mod_LoadAliasGroup (void * pin,  maliasframedesc_t *frame)
 {
 	daliasgroup_t		*pingroup;
 	int					i, numframes;
@@ -2385,7 +2394,6 @@ void *Mod_LoadAliasGroup (void * pin,  maliasframedesc_t *frame)
 		frame->bboxmax.v[i] = pingroup->bboxmax.v[i];
 	}
 
-
 	pin_intervals = (daliasinterval_t *)(pingroup + 1);
 
 	frame->interval = LittleFloat (pin_intervals->interval);
@@ -2438,7 +2446,7 @@ do {								\
 	else if (pos[off] != 255) fdc = pos[off];		\
 } while (0)
 
-void Mod_FloodFillSkin( byte *skin, int skinwidth, int skinheight )
+static void Mod_FloodFillSkin( byte *skin, int skinwidth, int skinheight )
 {
 	byte		fillcolor = *skin; // assume this is the pixel to fill
 	floodfill_t	fifo[FLOODFILL_FIFO_SIZE];
@@ -2451,11 +2459,13 @@ void Mod_FloodFillSkin( byte *skin, int skinwidth, int skinheight )
 		filledcolor = 0;
 		// attempt to find opaque black
 		for (i = 0; i < 256; ++i)
+		{
 			if (d_8to24table[i] == (255 << 0)) // alpha 1.0
 			{
 				filledcolor = i;
 				break;
 			}
+		}
 	}
 
 	// can't fill to filled color or to transparent color (used as visited marker)
@@ -2489,7 +2499,7 @@ void Mod_FloodFillSkin( byte *skin, int skinwidth, int skinheight )
 Mod_LoadAllSkins
 ===============
 */
-void *Mod_LoadAllSkins (int numskins, daliasskintype_t *pskintype)
+static void *Mod_LoadAllSkins (int numskins, daliasskintype_t *pskintype)
 {
 	int			i, j, k, size, groupskins;
 	char			name[MAX_QPATH];
@@ -2503,7 +2513,7 @@ void *Mod_LoadAllSkins (int numskins, daliasskintype_t *pskintype)
 	skin = (byte *)(pskintype + 1);
 
 	if (numskins < 1 || numskins > MAX_SKINS)
-		Sys_Error ("Mod_LoadAliasModel: Invalid # of skins: %d\n", numskins);
+		Sys_Error ("Mod_LoadAliasModel: Invalid # of skins: %d", numskins);
 
 	size = pheader->skinwidth * pheader->skinheight;
 
@@ -2601,7 +2611,7 @@ void *Mod_LoadAllSkins (int numskins, daliasskintype_t *pskintype)
 Mod_CalcAliasBounds -- johnfitz -- calculate bounds of alias model for nonrotated, yawrotated, and fullrotated cases
 =================
 */
-void Mod_CalcAliasBounds (aliashdr_t *a)
+static void Mod_CalcAliasBounds (aliashdr_t *a)
 {
 	int			i,j,k;
 	float		dist, yawradius, radius;
@@ -2706,7 +2716,9 @@ void Mod_SetExtraFlags (qmodel_t *mod)
 	if (!strcmp (mod->name, "progs/flame2.mdl") ||
 		!strcmp (mod->name, "progs/flame.mdl") ||
 		!strcmp (mod->name, "progs/boss.mdl"))
+	{
 		mod->flags |= MOD_FBRIGHTHACK;
+	}
 }
 
 /*
@@ -2714,7 +2726,7 @@ void Mod_SetExtraFlags (qmodel_t *mod)
 Mod_LoadAliasModel
 =================
 */
-void Mod_LoadAliasModel (qmodel_t *mod, void *buffer)
+static void Mod_LoadAliasModel (qmodel_t *mod, void *buffer)
 {
 	int					i, j;
 	mdl_t				*pinmodel;
@@ -2777,7 +2789,7 @@ void Mod_LoadAliasModel (qmodel_t *mod, void *buffer)
 	pheader->numframes = LittleLong (pinmodel->numframes);
 	numframes = pheader->numframes;
 	if (numframes < 1)
-		Sys_Error ("Mod_LoadAliasModel: Invalid # of frames: %d\n", numframes);
+		Sys_Error ("Mod_LoadAliasModel: Invalid # of frames: %d", numframes);
 
 	pheader->size = LittleFloat (pinmodel->size) * ALIAS_BASE_SIZE_RATIO;
 	mod->synctype = (synctype_t) LittleLong (pinmodel->synctype);
@@ -2790,7 +2802,6 @@ void Mod_LoadAliasModel (qmodel_t *mod, void *buffer)
 		pheader->eyeposition[i] = LittleFloat (pinmodel->eyeposition[i]);
 	}
 
-
 //
 // load the skins
 //
@@ -2875,7 +2886,7 @@ void Mod_LoadAliasModel (qmodel_t *mod, void *buffer)
 Mod_LoadSpriteFrame
 =================
 */
-void * Mod_LoadSpriteFrame (void * pin, mspriteframe_t **ppframe, int framenum)
+static void *Mod_LoadSpriteFrame (void * pin, mspriteframe_t **ppframe, int framenum)
 {
 	dspriteframe_t		*pinframe;
 	mspriteframe_t		*pspriteframe;
@@ -2923,7 +2934,7 @@ void * Mod_LoadSpriteFrame (void * pin, mspriteframe_t **ppframe, int framenum)
 Mod_LoadSpriteGroup
 =================
 */
-void * Mod_LoadSpriteGroup (void * pin, mspriteframe_t **ppframe, int framenum)
+static void *Mod_LoadSpriteGroup (void * pin, mspriteframe_t **ppframe, int framenum)
 {
 	dspritegroup_t		*pingroup;
 	mspritegroup_t		*pspritegroup;
@@ -2975,7 +2986,7 @@ void * Mod_LoadSpriteGroup (void * pin, mspriteframe_t **ppframe, int framenum)
 Mod_LoadSpriteModel
 =================
 */
-void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer)
+static void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer)
 {
 	int					i;
 	int					version;
@@ -3017,7 +3028,7 @@ void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer)
 // load the frames
 //
 	if (numframes < 1)
-		Sys_Error ("Mod_LoadSpriteModel: Invalid # of frames: %d\n", numframes);
+		Sys_Error ("Mod_LoadSpriteModel: Invalid # of frames: %d", numframes);
 
 	mod->numframes = numframes;
 
@@ -3052,7 +3063,7 @@ void Mod_LoadSpriteModel (qmodel_t *mod, void *buffer)
 Mod_Print
 ================
 */
-void Mod_Print (void)
+static void Mod_Print (void)
 {
 	int		i;
 	qmodel_t	*mod;
