@@ -83,6 +83,9 @@ cvar_t	temp1 = {"temp1","0",CVAR_NONE};
 
 cvar_t devstats = {"devstats","0",CVAR_NONE}; //johnfitz -- track developer statistics that vary every frame
 
+cvar_t	campaign = {"campaign","0",CVAR_NONE}; // for the 2021 rerelease
+cvar_t	horde = {"horde","0",CVAR_NONE}; // for the 2021 rerelease
+
 devstats_t dev_stats, dev_peakstats;
 overflowtimes_t dev_overflows; //this stores the last time overflow messages were displayed, not the last time overflows occured
 
@@ -130,7 +133,7 @@ void Host_EndGame (const char *message, ...)
 	if (cls.state == ca_dedicated)
 		Sys_Error ("Host_EndGame: %s\n",string);	// dedicated servers exit
 
-	if (cls.demonum != -1)
+	if (cls.demonum != -1 && !cls.timedemo)
 		CL_NextDemo ();
 	else
 		CL_Disconnect ();
@@ -281,6 +284,9 @@ void Host_InitLocal (void)
 	Cvar_RegisterVariable (&coop);
 	Cvar_RegisterVariable (&deathmatch);
 
+	Cvar_RegisterVariable (&campaign);
+	Cvar_RegisterVariable (&horde);
+
 	Cvar_RegisterVariable (&pausable);
 
 	Cvar_RegisterVariable (&temp1);
@@ -541,6 +547,7 @@ void Host_ClearMemory (void)
 	Con_DPrintf ("Clearing memory\n");
 	D_FlushCaches ();
 	Mod_ClearAll ();
+	Sky_ClearAll();
 /* host_hunklevel MUST be set at this point */
 	Hunk_FreeToLowMark (host_hunklevel);
 	cls.signon = 0;
@@ -570,7 +577,7 @@ qboolean Host_FilterTime (float time)
 	realtime += time;
 
 	//johnfitz -- max fps cvar
-	maxfps = CLAMP (10.0, host_maxfps.value, 1000.0);
+	maxfps = CLAMP (10.f, host_maxfps.value, 1000.f);
 	if (!cls.timedemo && realtime - oldrealtime < 1.0/maxfps)
 		return false; // framerate is too high
 	//johnfitz
@@ -868,6 +875,8 @@ void Host_Init (void)
 		CL_Init ();
 	}
 
+	LOC_Init (); // for 2021 rerelease support.
+
 	Hunk_AllocName (0, "-HOST_HUNKLEVEL-");
 	host_hunklevel = Hunk_LowMark ();
 
@@ -931,5 +940,6 @@ void Host_Shutdown(void)
 	}
 
 	LOG_Close ();
-}
 
+	LOC_Shutdown ();
+}
