@@ -91,7 +91,8 @@ static char *PF_VarString (int	first)
 	{
 		if (!dev_overflows.varstring || dev_overflows.varstring + CONSOLE_RESPAM_TIME < realtime)
 		{
-			Con_DWarning("PF_VarString: %i characters exceeds standard limit of 255 (max = %d).\n", (int) s, (int)(sizeof(out) - 1));
+			Con_DWarning("PF_VarString: %i characters exceeds standard limit of 255 (max = %d).\n",
+								(int) s, (int)(sizeof(out) - 1));
 			dev_overflows.varstring = realtime;
 		}
 	}
@@ -661,15 +662,6 @@ static void PF_sound (void)
 	volume = G_FLOAT(OFS_PARM3) * 255;
 	attenuation = G_FLOAT(OFS_PARM4);
 
-	if (volume < 0 || volume > 255)
-		Host_Error ("SV_StartSound: volume = %i", volume);
-
-	if (attenuation < 0 || attenuation > 4)
-		Host_Error ("SV_StartSound: attenuation = %f", attenuation);
-
-	if (channel < 0 || channel > 7)
-		Host_Error ("SV_StartSound: channel = %i", channel);
-
 	SV_StartSound (entity, channel, sample, volume, attenuation);
 }
 
@@ -970,24 +962,34 @@ static void PF_findradius (void)
 	edict_t	*ent, *chain;
 	float	rad;
 	float	*org;
-	vec3_t	eorg;
-	int	i, j;
+	int		i;
 
 	chain = (edict_t *)sv.edicts;
 
 	org = G_VECTOR(OFS_PARM0);
 	rad = G_FLOAT(OFS_PARM1);
+	rad *= rad;
 
 	ent = NEXT_EDICT(sv.edicts);
 	for (i = 1; i < sv.num_edicts; i++, ent = NEXT_EDICT(ent))
 	{
+		float d, lensq;
 		if (ent->free)
 			continue;
 		if (ent->v.solid == SOLID_NOT)
 			continue;
-		for (j = 0; j < 3; j++)
-			eorg[j] = org[j] - (ent->v.origin[j] + (ent->v.mins[j] + ent->v.maxs[j]) * 0.5);
-		if (VectorLength(eorg) > rad)
+
+		d = org[0] - (ent->v.origin[0] + (ent->v.mins[0] + ent->v.maxs[0]) * 0.5);
+		lensq = d * d;
+		if (lensq > rad)
+			continue;
+		d = org[1] - (ent->v.origin[1] + (ent->v.mins[1] + ent->v.maxs[1]) * 0.5);
+		lensq += d * d;
+		if (lensq > rad)
+			continue;
+		d = org[2] - (ent->v.origin[2] + (ent->v.mins[2] + ent->v.maxs[2]) * 0.5);
+		lensq += d * d;
+		if (lensq > rad)
 			continue;
 
 		ent->v.chain = EDICT_TO_PROG(chain);
@@ -1688,13 +1690,34 @@ static void PF_changelevel (void)
 
 /*
 ==============
-PF_finalefinished -- used by 2021 release.
+2021 re-release
 ==============
 */
 static void PF_finalefinished (void)
 {
 	G_FLOAT(OFS_RETURN) = 0;
 }
+static void PF_CheckPlayerEXFlags (void)
+{
+	G_FLOAT(OFS_RETURN) = 0;
+}
+static void PF_walkpathtogoal (void)
+{
+	G_FLOAT(OFS_RETURN) = 0; /* PATH_ERROR */
+}
+static void PF_localsound (void)
+{
+	const char	*sample;
+	int		entnum;
+
+	entnum = G_EDICTNUM(OFS_PARM0);
+	sample = G_STRING(OFS_PARM1);
+	if (entnum < 1 || entnum > svs.maxclients) {
+		Con_Printf ("tried to localsound to a non-client\n");
+		return;
+	}
+	SV_LocalSound (&svs.clients[entnum-1], sample);
+}
 
 static void PF_Fixme (void)
 {
@@ -1792,9 +1815,9 @@ static builtin_t pr_builtin[] =
 
 	PF_setspawnparms,
 
-	// 2021 release
+	// 2021 re-release
 	PF_finalefinished,	// float() finaleFinished = #79
-	PF_Fixme,		// void localsound (entity client, string sample) = #80
+	PF_localsound,		// void localsound (entity client, string sample) = #80
 	PF_Fixme,		// void draw_point (vector point, float colormap, float lifetime, float depthtest) = #81
 	PF_Fixme,		// void draw_line (vector start, vector end, float colormap, float lifetime, float depthtest) = #82
 	PF_Fixme,		// void draw_arrow (vector start, vector end, float colormap, float size, float lifetime, float depthtest) = #83
@@ -1804,11 +1827,12 @@ static builtin_t pr_builtin[] =
 	PF_Fixme,		// void draw_worldtext (string s, vector origin, float size, float lifetime, float depthtest) = #87
 	PF_Fixme,		// void draw_sphere (vector origin, float radius, float colormap, float lifetime, float depthtest) = #88
 	PF_Fixme,		// void draw_cylinder (vector origin, float halfHeight, float radius, float colormap, float lifetime, float depthtest) = #89
-	PF_centerprint ,	// #90
-	PF_bprint,
-	PF_sprint,
+
+	PF_CheckPlayerEXFlags,
+	PF_walkpathtogoal,
+
+	PF_Fixme,
 };
 
-builtin_t *pr_builtins = pr_builtin;
-int pr_numbuiltins = sizeof(pr_builtin)/sizeof(pr_builtin[0]);
-
+const builtin_t *pr_builtins = pr_builtin;
+const int pr_numbuiltins = sizeof(pr_builtin) / sizeof(pr_builtin[0]);
