@@ -35,6 +35,7 @@ static	ddef_t		*pr_fielddefs;
 static	ddef_t		*pr_globaldefs;
 
 qboolean	pr_alpha_supported; //johnfitz
+int		pr_effects_mask; // only enable 2021 rerelease quad/penta dlights when applicable
 
 dstatement_t	*pr_statements;
 globalvars_t	*pr_global_struct;
@@ -317,33 +318,33 @@ static const char *PR_ValueString (int type, eval_t *val)
 	switch (type)
 	{
 	case ev_string:
-		sprintf (line, "%s", PR_GetString(val->string));
+		q_snprintf (line, sizeof(line), "%s", PR_GetString(val->string));
 		break;
 	case ev_entity:
-		sprintf (line, "entity %i", NUM_FOR_EDICT(PROG_TO_EDICT(val->edict)) );
+		q_snprintf (line, sizeof(line), "entity %i", NUM_FOR_EDICT(PROG_TO_EDICT(val->edict)) );
 		break;
 	case ev_function:
 		f = pr_functions + val->function;
-		sprintf (line, "%s()", PR_GetString(f->s_name));
+		q_snprintf (line, sizeof(line), "%s()", PR_GetString(f->s_name));
 		break;
 	case ev_field:
 		def = ED_FieldAtOfs ( val->_int );
-		sprintf (line, ".%s", PR_GetString(def->s_name));
+		q_snprintf (line, sizeof(line), ".%s", PR_GetString(def->s_name));
 		break;
 	case ev_void:
-		sprintf (line, "void");
+		q_snprintf (line, sizeof(line), "void");
 		break;
 	case ev_float:
-		sprintf (line, "%5.1f", val->_float);
+		q_snprintf (line, sizeof(line), "%5.1f", val->_float);
 		break;
 	case ev_vector:
-		sprintf (line, "'%5.1f %5.1f %5.1f'", val->vector[0], val->vector[1], val->vector[2]);
+		q_snprintf (line, sizeof(line), "'%5.1f %5.1f %5.1f'", val->vector[0], val->vector[1], val->vector[2]);
 		break;
 	case ev_pointer:
-		sprintf (line, "pointer");
+		q_snprintf (line, sizeof(line), "pointer");
 		break;
 	default:
-		sprintf (line, "bad type %i", type);
+		q_snprintf (line, sizeof(line), "bad type %i", type);
 		break;
 	}
 
@@ -419,11 +420,11 @@ const char *PR_GlobalString (int ofs)
 	val = (void *)&pr_globals[ofs];
 	def = ED_GlobalAtOfs(ofs);
 	if (!def)
-		sprintf (line,"%i(?)", ofs);
+		q_snprintf (line, sizeof(line), "%i(?)", ofs);
 	else
 	{
 		s = PR_ValueString (def->type, (eval_t *)val);
-		sprintf (line,"%i(%s)%s", ofs, PR_GetString(def->s_name), s);
+		q_snprintf (line, sizeof(line), "%i(%s)%s", ofs, PR_GetString(def->s_name), s);
 	}
 
 	i = strlen(line);
@@ -442,9 +443,9 @@ const char *PR_GlobalStringNoContents (int ofs)
 
 	def = ED_GlobalAtOfs(ofs);
 	if (!def)
-		sprintf (line,"%i(?)", ofs);
+		q_snprintf (line, sizeof(line), "%i(?)", ofs);
 	else
-		sprintf (line,"%i(%s)", ofs, PR_GetString(def->s_name));
+		q_snprintf (line, sizeof(line), "%i(%s)", ofs, PR_GetString(def->s_name));
 
 	i = strlen(line);
 	for ( ; i < 20; i++)
@@ -923,7 +924,7 @@ const char *ED_ParseEdict (const char *data, edict_t *ent)
 
 		//johnfitz -- hack to support .alpha even when progs.dat doesn't know about it
 		if (!strcmp(keyname, "alpha"))
-			ent->alpha = ENTALPHA_ENCODE(atof(com_token));
+			ent->alpha = ENTALPHA_ENCODE(Q_atof(com_token));
 		//johnfitz
 
 		key = ED_FindField (keyname);
@@ -1041,6 +1042,93 @@ void ED_LoadFromFile (const char *data)
 }
 
 
+/*
+===============
+PR_HasGlobal
+===============
+*/
+static qboolean PR_HasGlobal (const char *name, float value)
+{
+	ddef_t *g = ED_FindGlobal (name);
+	return g && (g->type & ~DEF_SAVEGLOBAL) == ev_float && G_FLOAT (g->ofs) == value;
+}
+
+
+/*
+===============
+PR_FindSupportedEffects
+
+Checks for the presence of Quake 2021 release effects flags and returns a mask
+with the correspondings bits either on or off depending on the result, in order
+to avoid conflicts (e.g. Arcane Dimensions uses bit 32 for its explosions)
+===============
+*/
+static int PR_FindSupportedEffects (void)
+{
+	qboolean isqex = 
+		PR_HasGlobal ("EF_QUADLIGHT", EF_QEX_QUADLIGHT) &&
+		(PR_HasGlobal ("EF_PENTLIGHT", EF_QEX_PENTALIGHT) || PR_HasGlobal ("EF_PENTALIGHT", EF_QEX_PENTALIGHT))
+	;
+	return isqex ? -1 : -1 & ~(EF_QEX_QUADLIGHT|EF_QEX_PENTALIGHT|EF_QEX_CANDLELIGHT);
+}
+
+
+/*
+===============
+PR_PatchRereleaseBuiltins
+
+for 2021 re-release
+===============
+*/
+static const exbuiltin_t exbuiltins[] = {
+	/* Update-1 adds the following builtins with new ids. Patch them to use old indices.
+	 * (https://steamcommunity.com/games/2310/announcements/detail/2943653788150871156) */
+	{ "centerprint", -90, -73 },
+	{ "bprint", -91, -23 },
+	{ "sprint", -92, -24 },
+
+	/* Update-3 changes its unique builtins to be looked up by name instead of builtin
+	 * numbers, to avoid conflict with other engines. Patch them to use our indices.
+	 * (https://steamcommunity.com/games/2310/announcements/detail/3177861894960065435) */
+	{ "ex_centerprint", 0, -73 },
+	{ "ex_bprint", 0, -23 },
+	{ "ex_sprint", 0, -24 },
+	{ "ex_finaleFinished", 0, -79 },
+
+	{ "ex_localsound", 0, -80 },
+
+	{ "ex_draw_point", 0, -81 },
+	{ "ex_draw_line", 0, -82 },
+	{ "ex_draw_arrow", 0, -83 },
+	{ "ex_draw_ray", 0,  -84 },
+	{ "ex_draw_circle", 0, -85 },
+	{ "ex_draw_bounds", 0, -86 },
+	{ "ex_draw_worldtext", 0, -87 },
+	{ "ex_draw_sphere", 0, -88 },
+	{ "ex_draw_cylinder", 0, -89 },
+
+	{ "ex_CheckPlayerEXFlags", 0, -90 },
+	{ "ex_walkpathtogoal", 0,  -91 },
+	{ "ex_bot_movetopoint", 0, -92 },
+	{ "ex_bot_followentity", 0, -92 },
+
+	{ NULL, 0, 0 }			/* end-of-list. */
+};
+
+static void PR_PatchRereleaseBuiltins (void)
+{
+	const exbuiltin_t *ex = exbuiltins;
+	dfunction_t *f;
+
+	for ( ; ex->name != NULL; ++ex)
+	{
+		f = ED_FindFunction (ex->name);
+		if (f && f->first_statement == ex->first_statement)
+			f->first_statement = ex->patch_statement;
+	}
+}
+
+
 /*
 ===============
 PR_LoadProgs
@@ -1145,6 +1233,9 @@ void PR_LoadProgs (void)
 	// properly aligned
 	pr_edict_size += sizeof(void *) - 1;
 	pr_edict_size &= ~(sizeof(void *) - 1);
+
+	PR_PatchRereleaseBuiltins ();
+	pr_effects_mask = PR_FindSupportedEffects ();
 }
 
 
