@@ -870,6 +870,20 @@ void V_CalcRefdef (void)
 		Chase_UpdateForDrawing (); //johnfitz
 }
 
+/*
+==================
+V_RestoreAngles
+
+Resets the viewentity angles to the last values received from the server
+(undoing the manual adjustments performed by V_CalcRefdef)
+==================
+*/
+void V_RestoreAngles (void)
+{
+	entity_t *ent = &cl_entities[cl.viewentity];
+	VectorCopy (ent->msg_angles[0], ent->angles);
+}
+
 /*
 ==================
 V_RenderView
